summaryrefslogtreecommitdiff
path: root/gcc/ifcvt.c
diff options
context:
space:
mode:
authordanglin <danglin@138bc75d-0d04-0410-961f-82ee72b054a4>2003-01-21 02:03:14 +0000
committerdanglin <danglin@138bc75d-0d04-0410-961f-82ee72b054a4>2003-01-21 02:03:14 +0000
commitd7f916d2ea0322785a22015c5636ae30d2ebaad3 (patch)
treec2d8f35d93600c67ee74d2ea7536c57caf67e8f1 /gcc/ifcvt.c
parente30d7fb32dd92bf62aee970f9b1422201972804b (diff)
downloadgcc-d7f916d2ea0322785a22015c5636ae30d2ebaad3.tar.gz
* ifcvt.c (noce_emit_store_flag): Don't emit store flag if mode of x
is not a scalar int mode. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@61525 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/ifcvt.c')
-rw-r--r--gcc/ifcvt.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/ifcvt.c b/gcc/ifcvt.c
index 72dc2e12f65..6b069af265d 100644
--- a/gcc/ifcvt.c
+++ b/gcc/ifcvt.c
@@ -647,8 +647,8 @@ noce_emit_store_flag (if_info, x, reversep, normalize)
end_sequence ();
}
- /* Don't even try if the comparison operands are weird. */
- if (cond_complex)
+ /* Don't even try if the comparison operands or the mode of X are weird. */
+ if (cond_complex || !SCALAR_INT_MODE_P (GET_MODE (x)))
return NULL_RTX;
return emit_store_flag (x, code, XEXP (cond, 0),